@@ -1,7 +1,8 @@
 from ..manager import FullTextManager
 from ..manager import ImageManager
 from .model import PublishedApplicationResult
-from .schema import PublishedApplicationImageSchema, PublishedApplicationResultPageSchema
+from .schema import PublishedApplicationImageSchema
+from .schema import PublishedApplicationResultPageSchema
 from .schema import PublishedApplicationSchema
 from .settings import PUBLICATION_URL
 from .settings import SEARCH_FIELDS
